import{j as s,r as c,aF as m}from"./index-CULuikBf.js";function i({children:e,icon:r,items:a,title:n}){return s.jsxs("div",{className:"flex items-center gap-2 py-4 px-6 min-h-16.75 box-border bg-bg-secondary border-b border-border text-sm shrink-0",children:[s.jsxs("span",{className:"flex items-center gap-1.5",children:[s.jsx(r,{}),n]}),a.map((t,x)=>s.jsxs(c.Fragment,{children:[s.jsx(m,{className:"w-4 h-4"}),t]},x)),e]})}export{i as B};
